# Generated by Django 4.2.13 on 2024-06-13 09:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('niceauth', '0002_niceauthrequest_authtype_niceauthrequest_popupyn_and_more'),
    ]

    operations = [
        migrations.RenameField(
            model_name='niceauthresult',
            old_name='result_data',
            new_name='result',
        ),
    ]
