# Generated by Django 4.2.13 on 2024-06-13 09:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('niceauth', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='niceauthrequest',
            name='authtype',
            field=models.CharField(blank=True, max_length=20, null=True),
        ),
        migrations.AddField(
            model_name='niceauthrequest',
            name='popupyn',
            field=models.CharField(blank=True, max_length=1, null=True),
        ),
        migrations.AddField(
            model_name='niceauthrequest',
            name='return_url',
            field=models.URLField(blank=True, null=True),
        ),
    ]
